img_entries_mode

Function img_entries_mode 

pub fn img_entries_mode(
    child: impl IntoUiNode,
    mode: impl IntoVar<ImageEntriesMode>,
) -> UiNode
P Defines what images are decoded from multi image containers.

By default container types like TIFF or ICO only decode the first/largest image, this property defines if other contained images are also requested.

If the image contains a Reduced alternate the best size is used during rendering, this is particularly useful for displaying icon files that have symbolic alternates that are more readable at a smaller size.

You can also configure img_downscale to generate a mipmap as an optimization for displaying very large images.

Note that although it is possible to request multi pages here the widget does not support pages, it always displays the first/primary page. The image pages are decoded if requested and you can access the image variable to get the pages.

This property sets the IMAGE_ENTRIES_MODE_VAR.