mask_image_downscale

Function mask_image_downscale 

pub fn mask_image_downscale(
    child: impl IntoUiNode,
    downscale: impl IntoVar<Option<ImageDownscaleMode>>,
) -> UiNode
P Custom pixel resize applied during mask image load/decode.

Note that this resize affects the image actual pixel size directly when it is loading, it can also generate multiple image entries.

If the image is smaller than the requested size it is not upscaled. If multiple downscale samples are requested they are generated as synthetic ImageEntryKind::Reduced.

Changing this value after an image is already loaded or loading will cause the mask image to reload, image cache allocates different entries for different downscale values, prefer setting samples of all possible sizes at once to avoid generating multiple image entries in the cache.

This property sets the MASK_IMAGE_DOWNSCALE_VAR.