pub fn on_load_size_layout(
child: impl IntoUiNode,
handler: Handler<ImgLoadingArgs>,
) -> UiNodeExpand description
P Image loaded size metadata and layout event.
This property calls handler every first layout after the image changes size in a loaded window. If the window
is loading the call is delayed until it is loaded.
Handlers
This property accepts any Handler, including the async handlers. Use one of the handler macros, hn!,
hn_once!, async_hn! or async_hn_once!, to declare a handler closure.
Route
This property is not routed, it works only inside a widget that loads images. There is also no preview event.